<?php

namespace CRPlugins\Oca\Api;

abstract class ApiConnector {

	protected function exec( string $method, string $url, array $body, array $headers ): array {
		$args    = $this->before_request( $url, $method, $body, $headers );
		$request = wp_safe_remote_request( $url, $args );
		if ( is_wp_error( $request ) ) {
			throw new \Exception( 'There was an error with the request: ' . $request->get_error_message() );
		}

		$response    = wp_remote_retrieve_body( $request );
		$args['url'] = $url;
		return $this->after_request( $response, $args );
	}

	public function before_request( string $method, string $url, array $body, array $headers ): array {
		$request = array(
			'method'  => $method,
			'headers' => $headers,
		);
		if ( ! empty( $body ) ) {
			$request['body'] = $body;
		}
		return $request;
	}

	public function after_request( string $response, array $args ): array {
		return array(
			'response' => $response,
			'request'  => $args,
		);
	}

	public function get( string $endpoint, array $body = array(), array $headers = array() ) {
		$url = $this->get_base_url() . $endpoint;
		if ( ! empty( $body ) ) {
			$url .= '?' . http_build_query( $body );
		}
		return $this->exec( 'GET', $url, array(), $headers );
	}

	public function post( string $endpoint, array $body = array(), array $headers = array() ) {
		$url = $this->get_base_url() . $endpoint;
		return $this->exec( 'POST', $url, $body, $headers );
	}

	public function put( string $endpoint, array $body = array(), array $headers = array() ) {
		$url = $this->get_base_url() . $endpoint;
		return $this->exec( 'PUT', $url, $body, $headers );
	}

	public function delete( string $endpoint, array $body = array(), array $headers = array() ) {
		$url = $this->get_base_url() . $endpoint;
		return $this->exec( 'DELETE', $url, $body, $headers );
	}

	protected function add_params_to_url( $url, $params ) {
		if ( strpos( $url, '?' ) !== false ) {
			$url .= '&' . $params;
		} else {
			$url .= '?' . $params;
		}
		return $url;
	}

	abstract public function get_base_url();
}
