<?php

namespace CRPlugins\Oca\Helper;

use WC_Order_Item_Shipping;

class Helper {

	use NoticesTrait;
	use SettingsTrait;
	use WooCommerceTrait;
	use FilesTrait;

	public static function cart_method_is_oca( string $method_id ): array {
		$res       = array(
			'oca'    => false,
			'branch' => false,
		);
		$method_id = explode( '|', $method_id );
		if ( empty( $method_id ) ) {
			return $res;
		}
		if ( strpos( $method_id[0], 'oca:' ) === false || empty( $method_id[1] ) ) {
			return $res;
		}
		$res['oca'] = true;
		if ( 'branch' === $method_id[1] ) {
			$res['branch'] = true;
		}
		return $res;
	}

	public static function check_if_shipping_method_is_oca( string $method_id ): bool {
		return 'oca' === $method_id;
	}

	public static function shipping_method_is_oca( ?WC_Order_Item_Shipping $shipping_method ): bool {
		return $shipping_method && 'oca' === $shipping_method->get_method_id();
	}

	public static function get_order_shipping_method( \WC_Order $order ): ?WC_Order_Item_Shipping {
		$shipping_methods = $order->get_shipping_methods();
		if ( empty( $shipping_methods ) ) {
			return null;
		}

		$shipping_method = array_shift( $shipping_methods );
		return $shipping_method;
	}

	public static function order_is_sent_with_oca( \WC_Order $order ): bool {
		$shipping_method = self::get_order_shipping_method( $order );
		return self::shipping_method_is_oca( $shipping_method );
	}
}
