<?php

namespace CRPlugins\Oca\Helper;

use CRPlugins\Oca\Settings\Sections\OcaSection;
use CRPlugins\Oca\Settings\Sections\SellerSection;
use CRPlugins\Oca\ValueObjects\Seller;

trait SettingsTrait {

	public static function save_option( string $key, $value ): void {
		update_option( 'wc-oca-' . $key, $value );
	}

	public static function get_option( string $key, $default = false ) {
		return get_option( 'wc-oca-' . $key, $default );
	}

	public static function is_enabled( string $key, $default = false ): bool {
		return get_option( 'wc-oca-' . $key, $default ) === 'true';
	}

	public static function delete_option( string $key ): void {
		delete_option( 'wc-oca-' . $key );
	}

	public static function get_seller_from_settings(): Seller {
		$settings = array();

		// OCA Settings
		foreach ( OcaSection::get_fields() as $key => $value ) {
			$settings[ $key ] = self::get_option( $key );
		}
		foreach ( SellerSection::get_fields() as $key => $value ) {
			$settings[ $key ] = self::get_option( $key );
		}

		return new Seller( $settings );
	}

	public static function is_debug_enabled(): bool {
		return (string) Helper::get_option( 'debug' ) === 'true';
	}
}
