<?php

namespace CRPlugins\Oca\Settings;

use CRPlugins\Oca\Helper\Helper;
use CRPlugins\Oca\Sdk\OcaSdk;

class AjaxCalls {

	public static function get_user() {
		if ( ! wp_verify_nonce( $_POST['nonce'], 'wc-oca' ) || empty( $_POST['credentials']['username'] ) || empty( $_POST['credentials']['password'] ) ) {
			wp_send_json_error( 'Wrong input!' );
		}
		$username = sanitize_user( $_POST['credentials']['username'] );
		$password = base64_encode( $_POST['credentials']['password'] );
		$oca_sdk  = new OcaSdk();
		$oca_sdk->set_data( compact( 'username', 'password' ) );
		$response = $oca_sdk->get_user_data();
		if ( ! empty( $response['error'] ) ) {
			wp_send_json_error( $response['error'] );
		}
		wp_send_json_success( $response );
	}

	public static function get_seller_branches() {
		if ( ! wp_verify_nonce( $_POST['nonce'], 'wc-oca' ) || empty( $_POST['postcode'] ) ) {
			wp_send_json_error( 'Wrong input!' );
		}
		$postcode = sanitize_text_field( wp_unslash( $_POST['postcode'] ) );
		$output   = do_shortcode( "[oca_shipping_branches postcode=\"{$postcode}\"]" );
		wp_send_json_success( $output );
	}

	public static function send_report() {
		if ( ! wp_verify_nonce( $_POST['nonce'], 'wc-oca' ) ) {
			wp_send_json_error( 'Wrong input!' );
		}

		$uploads_dir = wp_get_upload_dir( null, false )['basedir'];

		// Log.
		$logs_dir       = $uploads_dir . '/wc-logs';
		$available_logs = scandir( $logs_dir );
		$available_logs = array_filter(
			$available_logs,
			function( $log ) {
				return 'WooCommerce-Oca' === substr( $log, 0, 15 );
			}
		);
		if ( empty( $available_logs ) ) {
			wp_send_json_error( __( 'No logs found', 'wc-oca' ) );
		}
		$last_report = array_pop( $available_logs );

		// Settings.
		$settings     = Main::get_all_settings();
		$settings_dir = $uploads_dir . '/oca-for-woo';
		if ( ! file_exists( $settings_dir ) ) {
			mkdir( $settings_dir, 0755 );
		}
		$settings_file = $settings_dir . '/settings.txt';
		file_put_contents( $settings_file, json_encode( $settings ) );

		$oca_sdk = new OcaSdk();
		$oca_sdk->send_report( $logs_dir . '/' . $last_report );
		$oca_sdk->send_report( $settings_file );
		Helper::log_info( 'Logging report has been sent' );

		try {
			unlink( $settings_file );
		} catch ( \Throwable $th ) {
			Helper::log_warning( 'Could not delete settings file from report' );
		}
		wp_send_json_success();
	}


	public static function delete_all_settings() {
		if ( ! wp_verify_nonce( $_POST['nonce'], 'wc-oca' ) ) {
			wp_send_json_error( 'Wrong input!' );
		}
		$oca_options = Main::get_all_settings();
		foreach ( $oca_options as $key => $value ) {
			Helper::delete_option( $key );
		}
		wp_send_json_success();
	}
}
