<?php

namespace CRPlugins\Oca\Settings\Sections;

/**
 * IntegrationSection class
 */
class IntegrationSection extends Section implements SectionInterface {

	private $data = array(
		'slug' => 'wc-oca-integration-settings',
	);

	/**
	 * Default constructor
	 */
	public function __construct() {
		$this->data['name'] = __( 'Integration settings', 'wc-oca' );
		parent::__construct( $this->data );
	}

	/**
	 * Gets all our fields in this section
	 *
	 * @return array
	 */
	public static function get_fields(): array {
		$fields   = array(
			'status_processing'               => array(
				'name'        => __( 'Status to process', 'wc-oca' ),
				'slug'        => 'status_processing',
				'description' => __( 'When an order has this status, it gets processed automatically with Oca.', 'wc-oca' ),
				'type'        => 'select',
				'default'     => 'wc-completed',
				'options'     => array(
					'0' => __( 'Disable automatic processing', 'wc-oca' ),
				),
			),
			'enable_insurance'                => array(
				'name'        => __( 'Enable Insurance', 'wc-oca' ),
				'slug'        => 'enable_insurance',
				'description' => __( 'Enables insurance for your shippings, this increases the price seen in the checkout. Up to 9 mil', 'wc-oca' ),
				'type'        => 'checkbox',
				'default'     => false,
			),
			'notify_customer_order_processed' => array(
				'name'        => __( 'Notify customer when an order is processed', 'wc-oca' ),
				'slug'        => 'notify_customer_order_processed',
				'description' => __( 'When an order is processed, automatically sends an email to the customer', 'wc-oca' ),
				'type'        => 'checkbox',
				'default'     => true,
			),
			'default_package_size'            => array(
				'name'        => __( 'Default package size', 'wc-oca' ),
				'slug'        => 'default_package_size',
				'description' => __( 'When you change the number of packages being shipped in an order, this size is used for each pacage, use format (Height)x(Width)x(Length), e.g. 0.5x0.2x0.2 (meters)', 'wc-oca' ),
				'type'        => 'text',
				'default'     => '0.5x0.2x0.2',
				'regexmask'   => '/^\d+[\.]{0,1}\d*+x\d+[\.]{0,1}\d*+x\d+[\.]{0,1}\d*$/',
			),
			'proccess_always_one_package'     => array(
				'name'        => __( 'Always send one package', 'wc-oca' ),
				'slug'        => 'proccess_always_one_package',
				'description' => __( 'Always send one package by default when processing an order', 'wc-oca' ),
				'type'        => 'checkbox',
			),
			'enable_branch_selector'          => array(
				'name'        => __( 'Enable Branch Selector', 'wc-oca' ),
				'slug'        => 'enable_branch_selector',
				'description' => __( 'Enables the branch selector in the checkout page, disable this if you are suffering from slow loading times or having issues with other shipping methods', 'wc-oca' ),
				'type'        => 'checkbox',
				'default'     => true,
			),
			'price_multiplier'                => array(
				'name'        => __( 'Price multiplier', 'wc-oca' ),
				'slug'        => 'price_multiplier',
				'description' => __( 'With this option you can multiply the final price received by OCA, i.e: enter 1.5 to increase the final price by 50%, or 0.8 to reduce the final price by 20%. Leave at 1 to disable.', 'wc-oca' ),
				'type'        => 'number',
				'default'     => 1,
				'step'        => 0.001,
			),
			'free_shipping_extra_name'        => array(
				'name'        => __( 'Extra name when shipping is free', 'wc-oca' ),
				'slug'        => 'free_shipping_extra_name',
				'description' => __( 'This name will be added at the end of the shipping method name when the shipping cost is free. Leave blank to disable.', 'wc-oca' ),
				'type'        => 'text',
				'default'     => __( 'Free', 'wc-oca' ),
			),
			'round_costs'                     => array(
				'name'        => __( 'Round shipping costs', 'wc-oca' ),
				'slug'        => 'round_costs',
				'description' => __( 'Round shipping costs to prevent decimals in the checkout', 'wc-oca' ),
				'type'        => 'checkbox',
			),
			'free_shipping_with_coupon'       => array(
				'name'        => __( 'Free shipping with coupon', 'wc-oca' ),
				'slug'        => 'free_shipping_with_coupon',
				'description' => __( 'When a free shipping coupon is added in the cart, the shipping cost becomes free', 'wc-oca' ),
				'type'        => 'checkbox',
				'default'     => true,
			),
			'debug'                           => array(
				'name'        => __( 'Enable debugging', 'wc-oca' ),
				'slug'        => 'debug',
				'description' => __( 'Enable the debug log for developers. If you do not know what is this then probably you do not need to enable it', 'wc-oca' ),
				'type'        => 'checkbox',
			),
			'send_report'                     => array(
				'name'        => __( 'Send Report', 'wc-oca' ),
				'slug'        => 'send_report',
				'type'        => 'ajaxbutton',
				'default'     => __( 'Send Report', 'wc-oca' ),
				'description' => __( 'Sends a logging report of your store to the CRPlugins team', 'wc-oca' ),
			),
		);
		$statuses = wc_get_order_statuses();
		foreach ( $statuses as $key => $status ) {
			$fields['status_processing']['options'][ $key ] = $status;
		}
		return $fields;
	}
}
