<?php

namespace CRPlugins\Oca\Settings\Sections;

use CRPlugins\Oca\Helper\Helper;

/**
 * OcaSection class
 */
class PluginSection extends Section implements SectionInterface {

	private $data = array(
		'slug' => 'wc-oca-plugin-settings',
	);

	/**
	 * Default constructor
	 */
	public function __construct() {
		$this->data['name'] = __( 'Plugin settings', 'wc-oca' );
		parent::__construct( $this->data );
	}

	/**
	 * Gets all our fields in this section
	 *
	 * @return array
	 */
	public static function get_fields(): array {
		$fields     = array(
			'apikey'     => array(
				'name' => __( 'API Key', 'wc-oca' ),
				'slug' => 'apikey',
				'type' => 'text',
			),
			'membership' => array(
				'name'        => __( 'Membership info', 'wc-oca' ),
				'slug'        => 'membership',
				'type'        => 'description',
				'description' => __( 'Enter your API Key in order to see membership details', 'wc-oca' ),
			),
		);
		$membership = Helper::get_option( 'membership', '' );
		if ( $membership ) {
			$exp_date = \DateTime::createFromFormat( 'Y-m-d H:i:s', $membership );
			$now      = new \DateTime();
			if ( $now < $exp_date ) {
				$fields['membership']['description'] = sprintf( __( 'Your license expires on %s', 'wc-oca' ), $exp_date->format( 'd/m/Y' ) );
			} else {
				$fields['membership']['description'] = sprintf( __( 'Your license expired on %s', 'wc-oca' ), $exp_date->format( 'd/m/Y' ) );
			}
		}
		return $fields;
	}
}
