<?php

namespace CRPlugins\Oca\Settings\Sections;

/**
 * SellerSection class
 */
class SellerSection extends Section implements SectionInterface {

	private $data = array(
		'slug' => 'wc-oca-seller-settings',
	);

	/**
	 * Default constructor
	 */
	public function __construct() {
		$this->data['name'] = __( 'Sender settings', 'wc-oca' );
		parent::__construct( $this->data );
	}

	/**
	 * Gets all our fields in this section
	 *
	 * @return array
	 */
	public static function get_fields(): array {
		return array(
			'name'           => array(
				'name' => __( 'Full name', 'wc-oca' ),
				'slug' => 'name',
				'type' => 'text',
			),
			'storeName'      => array(
				'name' => __( 'Store name', 'wc-oca' ),
				'slug' => 'storeName',
				'type' => 'text',
			),
			'email'          => array(
				'name' => __( 'Email', 'wc-oca' ),
				'slug' => 'email',
				'type' => 'text',
			),
			'street'         => array(
				'name'        => __( 'Street', 'wc-oca' ),
				'slug'        => 'street',
				'type'        => 'text',
				'description' => __( 'Example: Av. Belgrano', 'wc-oca' ),
			),
			'streetNumber'   => array(
				'name'        => __( 'Street number', 'wc-oca' ),
				'slug'        => 'streetNumber',
				'type'        => 'text',
				'description' => __( 'Example: 520', 'wc-oca' ),
			),
			'floor'          => array(
				'name'        => __( 'Floor (Optional)', 'wc-oca' ),
				'slug'        => 'floor',
				'type'        => 'text',
				'description' => __( 'Example: 2', 'wc-oca' ),
			),
			'apartment'      => array(
				'name'        => __( 'Apt. Number (Optional)', 'wc-oca' ),
				'slug'        => 'apartment',
				'type'        => 'text',
				'description' => __( 'Example: A', 'wc-oca' ),
			),
			'city'           => array(
				'name'        => __( 'City', 'wc-oca' ),
				'slug'        => 'city',
				'type'        => 'text',
				'description' => __( 'Example: Palermo', 'wc-oca' ),
			),
			'state'          => array(
				'name'        => __( 'State', 'wc-oca' ),
				'slug'        => 'state',
				'type'        => 'text',
				'description' => __( 'Example: Capital Federal', 'wc-oca' ),
			),
			'postcode'       => array(
				'name'        => __( 'Postal code', 'wc-oca' ),
				'slug'        => 'postcode',
				'type'        => 'text',
				'description' => __( 'Example: 1040', 'wc-oca' ),
			),
			'observations'   => array(
				'name'        => __( 'Notes about the direction', 'wc-oca' ),
				'slug'        => 'observations',
				'type'        => 'text',
				'description' => __( 'Example: Door bell does not work', 'wc-oca' ),
			),
			'timeFrame'      => array(
				'name'    => __( 'Time Frame', 'wc-oca' ),
				'slug'    => 'timeFrame',
				'type'    => 'select',
				'default' => '1',
				'options' => array(
					'1' => __( '8-17 Hrs', 'wc-oca' ),
					'2' => __( '8-12 Hrs', 'wc-oca' ),
					'3' => __( '14-17 Hrs', 'wc-oca' ),
				),
			),
			'shippingBranch' => array(
				'name'        => __( 'Shipping branch', 'wc-oca' ),
				'slug'        => 'shippingBranch',
				'description' => __( 'If you are going to send your packages from a Shipping branch, put the id here, otherwise leave it blank', 'wc-oca' ) . ' <a id="origin_shipping_branch_finder" href="#">' . __( 'Click here to find your shipping branch', 'wc-oca' ) . '</a>',
				'type'        => 'number',
			),
		);
	}
}
