<?php

namespace CRPlugins\Oca\Shortcodes;

use CRPlugins\Oca\Sdk\OcaSdk;

defined( 'ABSPATH' ) || exit;

class ShippingBranchesShortcode {

	public function __construct() {
		add_shortcode( 'oca_shipping_branches', array( $this, 'output' ) );
	}

	public function output( $atts ): string {
		$output = '';
		if ( empty( $atts['postcode'] ) ) {
			return $output;
		}

		$postcode = sanitize_text_field( $atts['postcode'] );
		$oca_sdk  = new OcaSdk();
		$branches = $oca_sdk->get_shipping_branches_from( $postcode );

		if ( isset( $branches['error'] ) ) {
			$output .= $this->show_error();
		} else {
			$output .= $this->results_table( $branches, $postcode );
		}
		return $output;
	}

	public function show_error(): string {
		return '<h3>' . __( 'There was an error, please try again', 'wc-oca' ) . '</h3>';
	}

	public function results_table( array $branches, string $postcode ): string {
		$output = '';
		if ( ! empty( $branches ) ) {
			$output .= '<table class="oca-table">';
			$output .= '<tr>';
			$output .= '<th width="5%">' . __( 'ID', 'wc-oca' ) . '</th>';
			$output .= '<th width="20%">' . __( 'Branch Office', 'wc-oca' ) . '</th>';
			$output .= '<th width="30%">' . __( 'Address', 'wc-oca' ) . '</th>';
			$output .= '<th width="10%">' . __( 'Phone', 'wc-oca' ) . '</th>';
			$output .= '<th width="20%">' . __( 'Schedule', 'wc-oca' ) . '</th>';
			$output .= '<th width="15%">' . __( 'Branch Office type', 'wc-oca' ) . '</th>';
			$output .= '</tr>';
			foreach ( $branches as $branch ) {
				$output .= '<tr>';
				$output .= "<td>{$branch['IdCentroImposicion']}</td>";
				$output .= "<td>{$branch['Sucursal']}</td>";
				$output .= '<td>';
				$output .= esc_html( $branch['Calle'] ) . ' ';
				$output .= esc_html( $branch['Numero'] );
				$output .= ! empty( $branch['Piso'] ) ? ' ' . esc_html( $branch['Piso'] ) : '';
				$output .= ! empty( $branch['Depto'] ) ? ' ' . esc_html( $branch['Depto'] ) : '';
				$output .= ', ';
				$output .= esc_html( $branch['Localidad'] ) . ' ';
				$output .= esc_html( $branch['CodigoPostal'] );
				$output .= '</td>';
				$output .= "<td>{$branch['Telefono']}</td>";
				$output .= "<td>{$branch['HorarioAtencion']}</td>";
				$output .= "<td>{$branch['TipoAgencia']}</td>";
				$output .= '</tr>';
			}
			$output .= '</table>';
		} else {
			$output .= '<h2>' . sprintf( __( 'Postcode %s without nearby shipping branches', 'wc-oca' ), $postcode ) . '</h2>';
		}
		return $output;
	}
}
