<?php

namespace CRPlugins\Oca\Shortcodes;

use CRPlugins\Oca\Sdk\OcaSdk;

defined( 'ABSPATH' ) || exit;

class TrackingShortcode {

	public function __construct() {
		add_shortcode( 'oca_order_tracking', array( $this, 'output' ) );
	}

	public function output( $atts ): string {
		$output = '';

		if ( ! isset( $_GET['with_form'] ) || 'yes' === $_GET['with_form'] ) {
			$output .= $this->form();
		}

		if ( ! empty( $_GET['oca_tracking_number'] ) ) {
			$tracking_number   = sanitize_text_field( wp_unslash( $_GET['oca_tracking_number'] ) );
			$oca_sdk           = new OcaSdk();
			$tracking_statuses = $oca_sdk->get_tracking( $tracking_number );
			if ( isset( $tracking_statuses['error'] ) ) {
				$output .= $this->error();
			} else {
				$output .= $this->results_table( $tracking_statuses, $tracking_number );
			}
		}

		return $output;
	}

	public function form(): string {
		return '<h2 class="oca-tracking-form-title">' . __( 'Shipment number', 'wc-oca' ) . '</h2>
        <form method="get" class="oca-tracking-form">
        <input type="text" name="oca_tracking_number" style="width:40%" class="oca-tracking-form-field"><br>
        <br />
        <input name="submit_button" type="submit"  value="' . __( 'Track shipment', 'wc-oca' ) . '"  id="update_button"  class="oca-tracking-form-submit update_button" style="cursor: pointer;background-color: #4fa0ff;border: 1px solid #4fa0ff;color: white;padding: 5px 10px;display: inline-block;border-radius: 4px;font-weight: 600;margin-bottom: 10px;text-align: center;"/>
        </form>';
	}

	public function error(): string {
		return '<h3 class="oca-tracking-error">' . __( 'There was an error, please try again', 'wc-oca' ) . '</h3>';
	}

	public function results_table( array $tracking_statuses, string $tracking_number ): string {
		$output = '';
		if ( ! empty( $tracking_statuses ) ) {
			$output .= '<h3>' . __( 'Shipment number', 'wc-oca' ) . ': ' . $tracking_number . '</h3>';
			$output .= '<table class="oca-table">';
			$output .= '<tr>';
			$output .= '<th width="15%">' . __( 'Date', 'wc-oca' ) . '</th>';
			$output .= '<th width="25%">' . __( 'Status', 'wc-oca' ) . '</th>';
			$output .= '<th width="20%">' . __( 'Status reason', 'wc-oca' ) . '</th>';
			$output .= '<th width="15%">' . __( 'Branch office', 'wc-oca' ) . '</th>';
			$output .= '<th width="25%">' . __( 'Branch office address', 'wc-oca' ) . '</th>';
			$output .= '</tr>';
			foreach ( $tracking_statuses as $tracking_status ) {
				$output .= '<tr>';
				$date    = new \DateTime( $tracking_status['Fecha'] );
				$output .= '<td>' . $date->format( 'd/m/Y' ) . '</td>';
				$output .= '<td>' . esc_html( $tracking_status['Estado'] ) . '</td>';
				$output .= '<td>' . esc_html( $tracking_status['Motivo'] ) . '</td>';
				$output .= '<td>' . esc_html( $tracking_status['Sucursal'] ) . '</td>';
				$output .= '<td>' . esc_html( $tracking_status['Sucursal_Direccion'] ) . '</td>';
				$output .= '</tr>';
			}
			$output .= '</table>';
		} else {
			$output .= '<h2>' . __( 'Shipment without status', 'wc-oca' ) . '</h2>';
		}
		return $output;
	}
}
