<?php

namespace CRPlugins\Oca\ValueObjects;

class CustomerAddress {
	/**
	 * @var string
	 */
	private $street;
	/**
	 * @var string
	 */
	private $number;
	/**
	 * @var string
	 */
	private $floor;
	/**
	 * @var string
	 */
	private $apartment;
	/**
	 * @var string
	 */
	private $postcode;
	/**
	 * @var string
	 */
	private $city;
	/**
	 * @var string
	 */
	private $state;

	public function __construct(
		string $street,
		string $number,
		string $floor,
		string $apartment,
		string $postcode,
		string $city,
		string $state
	) {
		$this->street    = $street;
		$this->number    = $number;
		$this->floor     = $floor;
		$this->apartment = $apartment;
		$this->postcode  = $postcode;
		$this->city      = $city;
		$this->state     = $state;
	}

	public function has_postcode(): bool {
		return ! empty( $this->postcode() );
	}

	public function postcode(): string {
		return $this->postcode;
	}

	public function full_address(): string {
		$full_address = $this->street();
		if ( ! empty( $this->number() ) ) {
			$full_address = sprintf( '%s %s', $full_address, $this->number() );
		}
		if ( ! empty( $this->floor() ) ) {
			$full_address = sprintf( '%s, %s', $full_address, $this->floor() );
			if ( ! empty( $this->apartment() ) ) {
				$full_address = sprintf( '%s %s', $full_address, $this->apartment() );
			}
		}

		$full_address = sprintf(
			'%s. %s %s, %s',
			$full_address,
			$this->city(),
			$this->postcode(),
			$this->state()
		);

		return $full_address;
	}

	public function street(): string {
		return $this->street;
	}

	public function number(): string {
		return $this->number;
	}

	public function floor(): string {
		return $this->floor;
	}

	public function apartment(): string {
		return $this->apartment;
	}

	public function city(): string {
		return $this->city;
	}

	public function state(): string {
		return $this->state;
	}
}
