<?php

namespace CRPlugins\Oca\ValueObjects;

class Items {

	/** @var Item[] */
	private $items;

	/**
	 * @var array
	 */
	private $totals;

	public function __construct(
		array $items
	) {
		$this->items = $items;
		$this->calculate_totals();
	}

	public function calculate_totals(): void {
		$totals = array(
			'weight'   => 0,
			'volume'   => 0,
			'price'    => 0,
			'quantity' => 0,
		);
		foreach ( $this->items as $item ) {
			$item_quantity = $item->quantity();
			for ( $i = 0; $i < $item_quantity; $i++ ) {
				$totals['weight'] += $item->weight();
				$totals['volume'] += $item->height() * $item->width() * $item->length();
				$totals['price']  += $item->price();
			}
			$totals['quantity'] += $item_quantity;
		}

		$this->totals = $totals;
	}

	public function totals(): array {
		return $this->totals;
	}

	public function set_items_price( float $price ) : void {
		$new_items = array_map(
			function ( Item $item ) use ( $price ) {
				$item->set_price( $price );
				return $item;
			},
			$this->items()
		);

		$this->set_items( $new_items );
	}

	public function items(): array {
		return $this->items;
	}

	private function set_items( array $items ): void {
		$this->items = $items;
		$this->calculate_totals();
	}

	public function set_totals_price( float $price ): void {
		$this->totals['price'] = $price;
	}

	public function set_custom_items_quantity( int $quantity, array $dimensions ): void {
		$name   = '';
		$price  = 0;
		$weight = 0;
		foreach ( $this->items as $item ) {
			$name   .= "{$item->quantity()}x {$item->name()}, ";
			$price  += ( $item->price() * $item->quantity() );
			$weight += ( $item->weight() * $item->quantity() );
		}

		// Remove ", " at the end.
		$name = substr( $name, 0, -2 );

		$new_item = new Item(
			$dimensions[0],
			$dimensions[1],
			$dimensions[2],
			$weight,
			$price,
			$name,
			$quantity,
			0
		);
		$this->set_items( array( $new_item ) );
	}
}
